@@ -167,11 +167,19 @@ class TestXml < Minitest::Test
   end
 
   def test_enabled_docbook
-    assert(LibXML::XML.enabled_docbook?)
+    if windows?
+      refute(LibXML::XML.enabled_docbook?)
+    else
+      assert(LibXML::XML.enabled_docbook?)
+    end
   end
 
   def test_enabled_ftp
-    assert(LibXML::XML.enabled_ftp?)
+    if windows?
+      refute(LibXML::XML.enabled_ftp?)
+    else
+      assert(LibXML::XML.enabled_ftp?)
+    end
   end
 
   def test_enabled_http
@@ -183,7 +191,8 @@ class TestXml < Minitest::Test
   end
 
   def test_enabled_iconv
-    assert(LibXML::XML.enabled_iconv?)
+    iconv_enabled = RUBY_PLATFORM !~ /darwin/
+    assert_equal(iconv_enabled, LibXML::XML.enabled_iconv?)
   end
 
   def test_enabled_memory_debug
@@ -241,7 +250,11 @@ class TestXml < Minitest::Test
   end
 
   def test_libxml_parser_features
-    assert_instance_of(Array, LibXML::XML.features)
+    if windows?
+      assert_nil(LibXML::XML.features)
+    else
+      assert_instance_of(Array, LibXML::XML.features)
+    end
   end
 
   def test_default_options
